/* fileio.h */


/* Library of file I/O functions usable on CRAY, SGI, Stellar, etc. */

#ifndef FILEIO_H
#define FILEIO_H





/*** read_int4 ********************************************************
   Read a 4-byte integer from a file.
   Input:  f - the file to read from
           i - pointer to integer to put result into.
   Returned:  0 = error, 1 = success
**********************************************************************/
extern int read_int4();
/*
FILE *f;
int *i;
*/




/*** read_float4 ******************************************************
   Read a 4-byte IEEE float from a file.
   Input:  f - the file to read from.
           x - pointer to float to put result into.
   Returned:  0 = error, 1 = success
**********************************************************************/
extern int read_float4();
/*
FILE *f;
float *x;
*/




/*** write_int4 *******************************************************
   Write a 4-byte integer to a file.
   Input:  f - the file
           i - the integer
   Return:  0 = error, 1 = success
**********************************************************************/
extern int write_int4();
/*
FILE *f;
int i;
*/




/*** write_float4 *****************************************************
   Write a 4-byte IEEE float to a file.
   Input:  f - the file
           x - the float
   Return:  0 = error, 1 = success
**********************************************************************/
extern int write_float4();
/*
FILE *f;
float x;
*/




/*** write_int4_array *************************************************
   Write an array of 'n' 4-byte integers to a file.
   Input:  f - the file
           i - the array of ints
	   n - the number of ints in array
   Return:  0 = error, 1 = success
**********************************************************************/
extern int write_int4_array();
/*
FILE *f;
int i[];
*/




/*** write_float4_array ***********************************************
   Write an array of 'n' 4-byte IEEE floating point numbers to a file.
   Input:  f - the file
           x - the array of floats
           n - number of floats in array
   Return:  0 = error, 1 = success.
**********************************************************************/
extern int write_float4_array();
/*
FILE *f;
float x[];
int n;
*/




/*** read_int4_array **************************************************
   Read an array of 'n' 4-byte integers from a file.
   Input:  f - the file
           i - the array of ints
	   n - the number of ints to read
   Return:  0 = error, 1 = success
**********************************************************************/
extern int read_int4_array();
/*
FILE *f;
int i[];
*/




/*** write_bytes ******************************************************
   Write an block of 'n' bytes to a file.
   Input:  f - the file
           b - pointer to buffer
	   n - number of bytes to write
   Return:  0 = error, 1 = success
**********************************************************************/
extern int write_bytes();
/*
FILE *f;
char *b;
int n;
*/



/*** read_bytes *******************************************************
   Read a block of 'n' bytes from a file.
   Input:  f - the file
           b - pointer to buffer
	   n - number of bytes to read
   Return:  0 = error, 1 = success
**********************************************************************/
extern int read_bytes();
/*
FILE *f;
char *b;
int n;
*/


#endif
